############################################################
#
# type definition pro_declaration_component_wlconfig
#
# RESPONSIBLE: Charles Loomis <charles.loomis@cern.ch>
#
# AUTHOR: Charles Loomis <charles.loomis@cern.ch>
#
# VERSION : 0.0.7
#
# Translation of edg-lcfg-wlconfig by Elisabetta Ronchieri.
#
############################################################

declaration template pro_declaration_component_wlconfig;

include pro_declaration_structures;

define type structure_wl_log = {
        "file"  : string
        "level" : long with (self>=0)
};

define type structure_wl_jobcontroller = {
        "condorSubmit"    : string
        "condorRemove"    : string
        "condorQuery"     : string
        "condorSubmitDAG" : string
        "condorRelease"   : string
        "container"       : long
        "submitFile"      : string
        "outputFile"      : string
        "queueFile"       : string
        "lockFile"        : string
        "log"             : structure_wl_log
};

define type structure_wl_logmonitor = {
        "jobsPerCondorLog"   : long with (self>=0)
        "mainLoopDuration"   : long with (self>=0)
        "condorLogDir"       : string
        "condorRecycleDir"   : string
        "monitorInternalDir" : string
        "idRepositoryName"   : string
        "abortedJobsTimeout" : long with (self>=0)
        "externalLogFile"    : string
        "lockFile"           : string
        "log"                : structure_wl_log
};

define type structure_wl_networkserver = {
        "iiPort"                : long with (self>0)
        "iiTimeout"             : long with (self>=0)
        "iiDN"                  : string
        "iiHost"                : type_hostname
        "grisPort"              : long with (self>0)
        "grisTimeout"           : long with (self>=0)
        "grisDN"                : string
        "backLogSize"           : long with (self>0)
        "listeningPort"         : long with (self>0)
        "masterThreads"         : long with (self>0)
        "dispatcherThreads"     : long with (self>0)
        "sandboxStagingPath"    : string
        "quotaManagement"       : boolean
        "quotaSandboxSize"      : long with (self>0)
        "quotaAdjustment"       : boolean
        "quotaAdjustmentAmount" : long with (self>0)
        "reservedDiskPercentage" : double with (self>=0.0 && self<=100.0)
        "log"                   : structure_wl_log
};

define type structure_wl_workloadmanager = {
        "pipeDepth"      : long with (self>0)
        "workerThreads"  : long with (self>0)
        "dispatcherType" : string
        "inputFile"      : string
        "maxRetryCount"  : long with (self>=0)
        "log"            : structure_wl_log
};


define type component_wlconfig = {
	include structure_component
        "configFile"      : string
        "user"            : string
        "hostProxyFile"   : string
        "grisCache"       : long with (self>=0)
        "useCachedResourceInfo" ? boolean
	"jobController"   : structure_wl_jobcontroller
	"logMonitor"      : structure_wl_logmonitor
	"networkServer"   : structure_wl_networkserver
	"workloadManager" : structure_wl_workloadmanager
};

type "/software/components/wlconfig" = component_wlconfig;
